<?php
/**
 * Helper functions for the admin - plugin links and help tabs.
 *
 * @package    Genesis Prose Extras
 * @subpackage Admin
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2013, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-prose-extras/
 * @link       http://deckerweb.de/twitter
 *
 * @since      1.0.0
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


/**
 * Setting internal plugin helper links constants.
 *
 * @since 1.0.0
 *
 * @uses  get_locale()
 */
define( 'GPEX_URL_TRANSLATE',		'http://translate.wpautobahn.com/projects/genesis-plugins-deckerweb/genesis-prose-extras' );
define( 'GPEX_URL_WPORG_FAQ',		'http://wordpress.org/extend/plugins/genesis-prose-extras/faq/' );
define( 'GPEX_URL_WPORG_FORUM',		'http://wordpress.org/support/plugin/genesis-prose-extras' );
define( 'GPEX_URL_WPORG_PROFILE',	'http://profiles.wordpress.org/daveshine/' );
define( 'GPEX_URL_SUPPORT',         esc_url( GPEX_URL_WPORG_FORUM ) );
define( 'GPEX_URL_DOCS',            esc_url( GPEX_URL_WPORG_FAQ ) );
define( 'GPEX_URL_SNIPPETS',		'https://gist.github.com/deckerweb/5905929' );
define( 'GPEX_PLUGIN_LICENSE', 		'GPL-2.0+' );
if ( get_locale() == 'de_DE' || get_locale() == 'de_AT' || get_locale() == 'de_CH' || get_locale() == 'de_LU' ) {
	define( 'GPEX_URL_DONATE', 		'http://genesisthemes.de/spenden/' );
	define( 'GPEX_URL_PLUGIN',		'http://genesisthemes.de/plugins/genesis-prose-extras/' );
} else {
	define( 'GPEX_URL_DONATE', 		'http://genesisthemes.de/en/donate/' );
	define( 'GPEX_URL_PLUGIN',		'http://genesisthemes.de/en/wp-plugins/genesis-prose-extras/' );
}


/**
 * Add "Settings Page" link to plugin page.
 *
 * @since  1.0.0
 *
 * @uses   admin_url()
 *
 * @param  $gpex_links
 * @param  $gpex_settings_link
 * @param  $gpex_widgets_link
 *
 * @return strings Settings Page & Widgets Page admin links.
 */
function ddw_gpex_settings_page_link( $gpex_links ) {

	/** Settings Page link */
	$gpex_settings_link = sprintf( '<a href="%s" title="%s">%s</a>' , admin_url( 'admin.php?page=gpex-prose-extras' ) , __( 'Go to the Plugin\'s settings page', 'genesis-prose-extras' ) , __( 'Settings', 'genesis-prose-extras' ) );

	/** Widgets Admin link */
	$gpex_widgets_link = sprintf( '<a href="%s" title="%s">%s</a>' , admin_url( 'widgets.php' ) , __( 'Go to the Widgets settings page', 'genesis-prose-extras' ) , __( 'Widgets', 'genesis-prose-extras' ) );

	/** Set the order of the links */
	array_unshift( $gpex_links, $gpex_settings_link, $gpex_widgets_link );

	/** Display plugin settings links */
	return apply_filters( 'gpex_filter_settings_page_link', $gpex_links );

}  // end of function ddw_gpex_settings_page_link


add_filter( 'plugin_row_meta', 'ddw_gpex_plugin_links', 10, 2 );
/**
 * Add various support links to plugin page.
 *
 * @since  1.0.0
 *
 * @param  $gpex_links
 * @param  $gpex_file
 *
 * @return strings plugin links
 */
function ddw_gpex_plugin_links( $gpex_links, $gpex_file ) {

	/** Capability check */
	if ( ! current_user_can( 'install_plugins' ) ) {

		return $gpex_links;

	}  // end-if cap check

	/** List additional links only for this plugin */
	if ( $gpex_file == GPEX_PLUGIN_BASEDIR . '/genesis-prose-extras.php' ) {

		$gpex_links[] = '<a href="' . esc_url( GPEX_URL_WPORG_FAQ ) . '" target="_new" title="' . __( 'FAQ', 'genesis-prose-extras' ) . '">' . __( 'FAQ', 'genesis-prose-extras' ) . '</a>';

		$gpex_links[] = '<a href="' . esc_url( GPEX_URL_WPORG_FORUM ) . '" target="_new" title="' . __( 'Support', 'genesis-prose-extras' ) . '">' . __( 'Support', 'genesis-prose-extras' ) . '</a>';

		$gpex_links[] = '<a href="' . esc_url( GPEX_URL_SNIPPETS ) . '" target="_new" title="' . __( 'Code Snippets for Customization', 'genesis-prose-extras' ) . '">' . __( 'Code Snippets', 'genesis-prose-extras' ) . '</a>';

		$gpex_links[] = '<a href="' . esc_url( GPEX_URL_TRANSLATE ) . '" target="_new" title="' . __( 'Translations', 'genesis-prose-extras' ) . '">' . __( 'Translations', 'genesis-prose-extras' ) . '</a>';

		$gpex_links[] = '<a href="' . esc_url( GPEX_URL_DONATE ) . '" target="_new" title="' . __( 'Donate', 'genesis-prose-extras' ) . '"><strong>' . __( 'Donate', 'genesis-prose-extras' ) . '</strong></a>';

	}  // end-if plugin links

	/** Output the links */
	return apply_filters( 'gpex_filter_plugin_links', $gpex_links );

}  // end of function ddw_gpex_plugin_links


add_action( 'sidebar_admin_setup', 'ddw_gpex_widgets_help' );
/**
 * Load plugin help tab after core help tabs on Widget admin page.
 *
 * @since  1.0.0
 *
 * @global mixed $pagenow
 */
function ddw_gpex_widgets_help() {

	/** Get the page hook */
	global $pagenow;

	add_action( 'admin_head-' . $pagenow, 'ddw_gpex_help_tab' );

}  // end of function ddw_gpex_widgets_help


add_action( 'load-toplevel_page_genesis', 'ddw_gpex_help_tab', 16 );				// Genesis Core
add_action( 'load-genesis_page_seo-settings', 'ddw_gpex_help_tab', 16 );			// Genesis SEO
add_action( 'load-genesis_page_genesis-import-export', 'ddw_gpex_help_tab', 16 );	// Genesis Import/Export
add_action( 'load-genesis_page_design-settings', 'ddw_gpex_help_tab', 16 );			// Prose Child Theme
add_action( 'load-genesis_page_prose-custom', 'ddw_gpex_help_tab', 16 );			// Prose Custom Section
/**
 * Create and display plugin help tab.
 *
 * @since  1.0.0
 *
 * @uses   get_current_screen()
 * @uses   WP_Screen::add_help_tab()
 * @uses   WP_Screen::set_help_sidebar()
 * @uses   ddw_gpex_help_sidebar_content()
 *
 * @global mixed $gpex_screen, $pagenow
 */
function ddw_gpex_help_tab() {

	/** Get global helper variables */
	global $gpex_screen, $pagenow;

	$gpex_screen = get_current_screen();

	/** Display help tabs only for WordPress 3.3 or higher */
	if ( ! class_exists( 'WP_Screen' )
		|| ! $gpex_screen
		|| basename( get_template_directory() ) != 'genesis'
	) {
		return;
	}

	/** Add the new help tab */
	$gpex_screen->add_help_tab( array(
		'id'       => 'gpex-prose-help',
		'title'    => __( 'Genesis Prose Extras', 'genesis-prose-extras' ),
		'callback' => apply_filters( 'gpex_filter_help_content_genesis', 'ddw_gpex_help_content' ),
	) );

	/** Add help sidebar */
	if ( $pagenow != 'widgets.php' ) {

		$gpex_screen->set_help_sidebar( ddw_gpex_help_sidebar_content() );

	}  // end-if $pagehook check

}  // end of function ddw_gpex_help_tab


add_action( 'admin_head-edit.php', 'ddw_gpex_help_tab_edit_screens', 15 );
add_action( 'admin_head-post.php', 'ddw_gpex_help_tab_edit_screens', 15 );
add_action( 'admin_head-post-new.php', 'ddw_gpex_help_tab_edit_screens', 15 );
/**
 * Create and display plugin Shortcode help tab for the post type edit screens.
 *
 * @since  1.0.0
 *
 * @uses   get_current_screen()
 * @uses   current_user_can()
 * @uses   get_post_type()
 * @uses   get_the_ID()
 * @uses   post_type_supports()
 * @uses   WP_Screen::add_help_tab()
 *
 * @global mixed $gpex_screen, $post
 */
function ddw_gpex_help_tab_edit_screens() {

	global $gpex_screen, $post;

	$gpex_screen = get_current_screen();

	/** Display help tabs only for WordPress 3.3 or higher */
	if ( ! class_exists( 'WP_Screen' )
		|| ! $gpex_screen
	) {
		return;
	}

	/** Add general "Custom CSS" + "Shortcode" help tab */
	if ( in_array( $gpex_screen->base, array( 'edit', 'post', 'post-new' ) )
		&& ( get_post_type( get_the_ID() ) === $gpex_screen->post_type /* || 'page' == $gpex_screen->post_type */ )
		&& ( defined( 'PROSE_DOMAIN' ) )
	) {

		if ( current_user_can( ddw_gpex_inpost_custom_css_cap() )
			&& ( post_type_supports( get_post_type( get_the_ID() ), 'gpex-inpost-css' ) )
		) {

			$gpex_screen->add_help_tab( array(
				'id'       => 'gpex-custom-css-help',
				'title'    => _x( 'Genesis Prose Extras', 'Translators: admin plugin title', 'genesis-prose-extras' ) . ': ' . __( 'Custom CSS', 'genesis-prose-extras' ),
				'callback' => apply_filters( 'gpex_filter_help_content_custom_css', 'ddw_gpex_help_content_inpost_screens' ),
			) );

		}

		if ( post_type_supports( get_post_type( get_the_ID() ), 'genesis-layouts' ) ) {

			$gpex_screen->add_help_tab( array(
				'id'       => 'gpex-layout-extras-help',
				'title'    => _x( 'Genesis Prose Extras', 'Translators: admin plugin title', 'genesis-prose-extras' ) . ': ' . __( 'Layouts', 'genesis-prose-extras' ),
				'callback' => apply_filters( 'gpex_filter_help_content_layout_extras', 'ddw_gpex_help_content_layout_extras' ),
			) );

		}

		$gpex_screen->add_help_tab( array(
			'id'       => 'gpex-shortcodes-help',
			'title'    => _x( 'Genesis Prose Extras', 'Translators: admin plugin title', 'genesis-prose-extras' ) . ': ' . __( 'Shortcodes', 'genesis-prose-extras' ),
			'callback' => apply_filters( 'gpex_filter_help_content_shortcodes', 'ddw_gpex_help_content_shortcodes' ),
		) );

	}  // end-if pagehook check

}  // end of function ddw_gpex_help_tab_edit_screens


/**
 * Display the plugin title/version headline for help tabs.
 *
 * @since 1.0.0
 *
 * @uses  ddw_gpex_plugin_get_data() To display various data of this plugin.
 */
function ddw_gpex_help_content_headline() {

	echo '<h3>' . __( 'Plugin', 'genesis-prose-extras' ) . ': ' . __( 'Genesis Prose Extras', 'genesis-prose-extras' ) . ' <small>v' . esc_attr( ddw_gpex_plugin_get_data( 'Version' ) ) . '</small></h3>';

}  // end of function ddw_gpex_help_content_headline


/**
 * Display the plugin footer/legal info for help tabs.
 *
 * @since 1.0.0
 *
 * @uses  ddw_gpex_plugin_get_data() To display various data of this plugin.
 */
function ddw_gpex_help_content_footer() {

	echo '<p><strong>' . __( 'Important plugin links:', 'genesis-prose-extras' ) . '</strong>' . 
		'<br /><a href="' . esc_url( GPEX_URL_PLUGIN ) . '" target="_new" title="' . __( 'Plugin website', 'genesis-prose-extras' ) . '">' . __( 'Plugin website', 'genesis-prose-extras' ) . '</a> | <a href="' . esc_url( GPEX_URL_WPORG_FAQ ) . '" target="_new" title="' . __( 'FAQ', 'genesis-prose-extras' ) . '">' . __( 'FAQ', 'genesis-prose-extras' ) . '</a> | <a href="' . esc_url( GPEX_URL_WPORG_FORUM ) . '" target="_new" title="' . __( 'Support', 'genesis-prose-extras' ) . '">' . __( 'Support', 'genesis-prose-extras' ) . '</a> | <a href="' . esc_url( GPEX_URL_SNIPPETS ) . '" target="_new" title="' . __( 'Code Snippets for Customization', 'genesis-prose-extras' ) . '">' . __( 'Code Snippets', 'genesis-prose-extras' ) . '</a> | <a href="' . esc_url( GPEX_URL_TRANSLATE ) . '" target="_new" title="' . __( 'Translations', 'genesis-prose-extras' ) . '">' . __( 'Translations', 'genesis-prose-extras' ) . '</a> | <a href="' . esc_url( GPEX_URL_DONATE ) . '" target="_new" title="' . __( 'Donate', 'genesis-prose-extras' ) . '"><strong>' . __( 'Donate', 'genesis-prose-extras' ) . '</strong></a></p>';

	echo '<p><a href="http://www.opensource.org/licenses/gpl-license.php" target="_new" title="' . esc_attr( GPEX_PLUGIN_LICENSE ). '">' . esc_attr( GPEX_PLUGIN_LICENSE ). '</a> &copy; ' . date( 'Y' ) . ' <a href="' . esc_url( ddw_gpex_plugin_get_data( 'AuthorURI' ) ) . '" target="_new" title="' . esc_attr__( ddw_gpex_plugin_get_data( 'Author' ) ) . '">' . esc_attr__( ddw_gpex_plugin_get_data( 'Author' ) ) . '</a></p>';

}  // end of function ddw_gpex_help_content_footer


/**
 * Create and display default plugin help tab content.
 *
 * @since 1.0.0
 *
 * @uses  ddw_gpex_help_content_headline() To display plugin headline.
 * @uses  ddw_gpex_help_content_plugin_info() To display general plugin info.
 * @uses  ddw_gpex_help_content_widget_areas() To display widget area info.
 * @uses  ddw_gpex_help_content_shortcodes_params() To display Shortcode params.
 * @uses  ddw_gpex_help_content_footer() To display plugin info footer.
 * @uses  ddw_gpex_space_helper() To add whitespace.
 */
function ddw_gpex_help_content() {

	ddw_gpex_help_content_headline();

	echo ddw_gpex_help_content_plugin_info();
		echo ddw_gpex_space_helper();	// space only

	echo ddw_gpex_help_content_widget_areas();
		echo ddw_gpex_space_helper();	// space only

	ddw_gpex_help_content_layouts_info();
		echo ddw_gpex_space_helper();	// space only

	ddw_gpex_help_content_shortcodes_params();
		echo ddw_gpex_space_helper();	// space only

	ddw_gpex_help_content_footer();

}  // end of function ddw_gpex_help_content


/**
 * Create and display plugin help tab content for "Plugin Info" part.
 *
 * @since  1.0.0
 *
 * @param  $gpex_usage_content_one
 *
 * @return string HTML help content plugin info/ start.
 */
function ddw_gpex_help_content_plugin_info() {

	$gpex_plugin_info_content = '<p><strong>' . __( 'Safe on automatic updates', 'genesis-prose-extras' ) . ':</strong>' .
		'<br />' . __( 'All additions of this plugin, especially the virtual home page template plus the additional widget areas, are safe if you process automatic updates for Prose provided by StudioPress. The Prose child theme folder is NEVER touched by this plugin.', 'genesis-prose-extras' ) .
		'</p>' .
		'<p><strong>' . __( 'Styling for widgetized home page', 'genesis-prose-extras' ) . ':</strong>' .
		'<br />' . sprintf( __( 'There are no extra frontend styles shipped with this plugin. Prose has an awesome %s section and you should leverage that for all additional styling rules.', 'genesis-prose-extras' ), '<a href="' . admin_url( 'admin.php?page=prose-custom#prose-custom-css' ) . '">' . __( 'Custom CSS', 'genesis-prose-extras' ) . '</a>' ) .
		'</p>';

	return apply_filters( 'gpex_filter_help_plugin_info_content', $gpex_plugin_info_content );

}  // end of function ddw_gpex_help_content_plugin_info


/**
 * Create and display plugin help tab content for "Widgets Areas" part.
 *
 * @since  1.0.0
 *
 * @param  string 	$gpex_enabled
 * @param  string 	$gpex_content_tag
 * @param  string 	$gpex_column
 * @param  string 	$gpex_widget_areas_content
 * @param  string 	$gpex_widget_areas_shortcodes
 *
 * @return string HTML help content widget areas.
 */
function ddw_gpex_help_content_widget_areas() {

	/** Helper style */
	$gpex_enabled = __( 'Default: enabled', 'genesis-prose-extras' );
	$gpex_content_tag = ( function_exists( 'genesis_html5' ) && genesis_html5() ) ? 'main.content' : '#content';
	$gpex_column = sprintf( __(' Width: %s', 'genesis-prose-extras' ), '<code>' . $gpex_content_tag . '</code> ' . __( '50% column', 'genesis-prose-extras' ) );

	$gpex_widget_areas_content = '<p><strong>' . __( 'Added Widget areas by the plugin', 'genesis-prose-extras' ) . ':</strong>' .
		'<br />' . __( 'Generally, these are controlled via plugin settings and only displayed if having active widgets placed in:', 'genesis-prose-extras' ) . '</p>' .
		'<ul>' . 
			'<li><strong><em>' . __( 'Prose Home Top', 'genesis-prose-extras' ) . '</em></strong> &ndash; ' . $gpex_enabled . ' / ' . sprintf( __(' Width: %s', 'genesis-prose-extras' ), '<code>' . $gpex_content_tag . '</code> ' . __( 'default', 'genesis-prose-extras' ) ) . ' / ' . sprintf( __( 'ID: %s', 'genesis-prose-extras' ), '<code>gpex-prose-home-top</code>' ) . '</li>' .
			'<li><strong><em>' . __( 'Prose Home Left', 'genesis-prose-extras' ) . '</em></strong> &ndash; ' . $gpex_enabled . ' / ' . $gpex_column . ' / ' . sprintf( __( 'ID: %s', 'genesis-prose-extras' ), '<code>gpex-prose-home-left</code>' ) . '</li>' .
			'<li><strong><em>' . __( 'Prose Home Right', 'genesis-prose-extras' ) . '</em></strong> &ndash; ' . $gpex_enabled . ' / ' . $gpex_column . ' / ' . sprintf( __( 'ID: %s', 'genesis-prose-extras' ), '<code>gpex-prose-home-right</code>' ) . '</li>' .
			'<li><strong><em>' . __( 'Prose Home Sidebar', 'genesis-prose-extras' ) . '</em></strong> &ndash; ' . __( 'Default: disabled', 'genesis-prose-extras' ) . ' / ' . sprintf( __( 'Note: This will replace the default %s.', 'genesis-prose-extras' ), '<em>&raquo;' . __( 'Primary Sidebar', 'genesis-prose-extras' ) . '&laquo;</em>' ) . ' / ' . sprintf( __( 'ID: %s', 'genesis-prose-extras' ), '<code>gpex-prose-home-extra</code>' ) . '</li>' .
			'<li><strong><em>' . __( 'Prose After Page', 'genesis-prose-extras' ) . '</em></strong> &ndash; ' . $gpex_enabled . ' / ' . sprintf( __( 'ID: %s', 'genesis-prose-extras' ), '<code>gpex-prose-after-page</code>' ) . '</li>' .
		'</ul>';

	/** Widgets shortcode support */
	if ( ! GPEX_NO_WIDGETS_SHORTCODE ) {

		$gpex_widget_areas_shortcodes = '<p>&rarr; ' . __( 'Shortcodes are supported in all five widget areas.', 'genesis-prose-extras' ) . '</p>';

	} else {

		$gpex_widget_areas_shortcodes = '';

	}  // end-if widgets shortcode check

	return apply_filters( 'gpex_filter_help_widget_areas_content', $gpex_widget_areas_content . $gpex_widget_areas_shortcodes );

}  // end of function ddw_gpex_help_content_widget_areas


/**
 * Strings of HTML content for Shortcode parameters.
 *
 * @since 1.0.0
 */
function ddw_gpex_help_content_shortcodes_params() {

	/** Shortcode info, plus parameters */
	echo '<p><strong>' . __( 'Provided Shortcodes by the plugin:', 'genesis-prose-extras' ) . '</strong></p>' .
		'<p><code>[gpex_widget_area]</code></p>' .
		'<blockquote><ul>' .
			'<li><em>' . __( 'Supporting the following parameters', 'genesis-prose-extras' ) . ':</em></li>' .
			'<li><code>area</code> &mdash; ' . __( 'ID of the Widget area (Sidebar; see above)', 'genesis-prose-extras' ) . ' &mdash; ' . sprintf( __( 'Default: %s', 'genesis-prose-extras' ), '<em>' . __( 'none, empty', 'genesis-prose-extras' ) . '</em>' ) . '</li>' .
		'</ul></blockquote>' .
		'<p><code>[gpex_post_categories]</code></p>' .
		'<blockquote><ul>' .
			'<li><em>' . __( 'Supporting the following parameters', 'genesis-prose-extras' ) . ':</em></li>' .
			'<li><code>sep</code> &mdash; ' . __( 'Separator', 'genesis-prose-extras' ) . ' &mdash; ' . sprintf( __( 'Default: %s', 'genesis-prose-extras' ), '<code>, </code>' ) . '</li>' .
			'<li><code>before</code> &mdash; ' . __( 'Text or HTML before categories list', 'genesis-prose-extras' ) . ' &mdash; ' . sprintf( __( 'Default: %s', 'genesis-prose-extras' ), '<em>' . __( 'none, empty', 'genesis-prose-extras' ) . '</em>' ) . '</li>' .
			'<li><code>after</code> &mdash; ' . __( 'Text or HTML after categories list', 'genesis-prose-extras' ) . ' &mdash; ' . sprintf( __( 'Default: %s', 'genesis-prose-extras' ), '<em>' . __( 'none, empty', 'genesis-prose-extras' ) . '</em>' ) . '</li>' .
			'<li><code>class</code> &mdash; ' . __( 'Can be a custom class, added to the wrapper tag', 'genesis-prose-extras' ) . ' &mdash; ' . sprintf( __( 'Default: %s', 'genesis-prose-extras' ), '<em>' . __( 'none, empty', 'genesis-prose-extras' ) . '</em>' ) . '</li>' .
		'</ul></blockquote>';

}  // end of function ddw_gpex_help_content_shortcodes_params


/**
 * Strings of HTML content for Custom CSS info/ advise.
 *
 * @since 1.0.0
 */
function ddw_gpex_help_content_custom_css_advice() {

	/** Custom CSS advise */
	echo '<p>' . sprintf(
					__( 'Additional meta boxes, by default added to inpost edit screens for %s and %s.', 'genesis-prose-extras' ),
					'<a href="' . admin_url( 'edit.php' ) . '">' . __( 'Posts', 'genesis-prose-extras' ) . '</a>',
					'<a href="' . admin_url( 'edit.php?post_type=page' ) . '">' . __( 'Pages', 'genesis-prose-extras' ) . '</a>'
			) . '</p>' .
		'<ul>' .
			'<li>' . __( 'Very handy for small additions for singular posts/ pages (post types). No need to touch the Design Settings or Prose (global) Custom CSS. Also, no need for body/ post classes.', 'genesis-prose-extras' ) . '</li>' .
			'<li>' . __( 'As I said, small additions. Huge amounts of CSS should be added via Prose\' own CSS page or via extra stylesheet.', 'genesis-prose-extras' ) . '</li>' .
			'<li>' . __( 'Developers/ Webmasters can add support for other post types.', 'genesis-prose-extras' ) . ' (<a href="' . esc_url( GPEX_URL_SNIPPETS ) . '" target="_new" title="' . __( 'Code Snippets for Customization', 'genesis-prose-extras' ) . '">' . __( 'Code Snippets', 'genesis-prose-extras' ) . '</a>)</li>' .
		'</ul>';

}  // end of function ddw_gpex_help_content_custom_css_advice


/**
 * Strings of HTML content for Layout Extras info.
 *
 * @since 1.1.0
 */
function ddw_gpex_help_content_layouts_info() {

	/** Custom CSS advise */
	echo '<p><strong>' . __( 'Additional, alternate layout options', 'genesis-prose-extras' ) . '</strong></p>' .
			'Consider these more like variations of existing layouts. So, in the end you have even more flexibility with no overhead! This could be great for content oriented blogs, marketeers websites and so much more...' .
			'<ul>' .
				'<li><em>' . __( 'Sidebars below Content', 'genesis-prose-extras' ) . '</em> &ndash; ' . sprintf( __( 'Think of it as %s, but with Primary and Secondary sidebars below the content (as two fifty percent-wide responsive columns).', 'genesis-prose-extras' ), '"' . __( 'Full-Width-Content', 'genesis-prose-extras' ) . '"' ) . '</li>' .
				'<li><em>' . __( 'Content/Sidebar-Alt', 'genesis-prose-extras' ) . '</em> &ndash; ' . sprintf( __( 'Think of it as a variation of %s.', 'genesis-prose-extras' ), '"' . __( 'Content-Sidebar', 'genesis-prose-extras' ) . '"' ) . '</li>' .
				'<li><em>' . __( 'Sidebar-Alt/Content', 'genesis-prose-extras' ) . '</em> &ndash; ' . sprintf( __( 'Think of it as a variation of %s.', 'genesis-prose-extras' ), '"' . __( 'Sidebar-Content', 'genesis-prose-extras' ) . '"' ) . '</li>' .
			'</ul>' .
			'<p>' . __( 'These alternate layouts are fully responsive. All is working like it should with minimal additions on CSS style rules (only what\'s really needed).', 'genesis-prose-extras' ) . '</p>';

}  // end of function ddw_gpex_help_content_layouts_info


/**
 * Add help tab content for plugin's Custom CSS (inpost screens).
 *
 * @since 1.0.0
 *
 * @uses  ddw_gpex_help_content_headline()
 * @uses  ddw_gpex_help_content_custom_css_advice()
 * @uses  ddw_gpex_help_content_footer()
 */
function ddw_gpex_help_content_inpost_screens() {

	ddw_gpex_help_content_headline();

	ddw_gpex_help_content_custom_css_advice();

	ddw_gpex_help_content_footer();

}  // end of function ddw_gpex_help_content_inpost_screens


/**
 * Add help tab content for plugin's Custom CSS (inpost screens).
 *
 * @since 1.1.0
 *
 * @uses  ddw_gpex_help_content_headline()
 * @uses  ddw_gpex_help_content_layouts_info()
 * @uses  ddw_gpex_help_content_footer()
 */
function ddw_gpex_help_content_layout_extras() {

	ddw_gpex_help_content_headline();

	ddw_gpex_help_content_layouts_info();

	ddw_gpex_help_content_footer();

}  // end of function ddw_gpex_help_content_layout_extras


/**
 * Add help tab content for plugin's Shortcodes.
 *
 * @since 1.0.0
 *
 * @uses  ddw_gpex_help_content_headline()
 * @uses  ddw_gpex_help_content_shortcodes_params()
 * @uses  ddw_gpex_help_content_footer()
 * @uses  ddw_gpex_space_helper()
 */
function ddw_gpex_help_content_shortcodes() {

	ddw_gpex_help_content_headline();

	echo ddw_gpex_space_helper();	// space only
	ddw_gpex_help_content_shortcodes_params();

	ddw_gpex_help_content_footer();

}  // end of function ddw_gpex_help_content_shortcodes


/**
 * Helper function for returning the Help Sidebar content.
 *
 * @since  1.0.0
 *
 * @uses   ddw_gpex_plugin_get_data() To display various data of this plugin.
 *
 * @param  $gpex_help_sidebar_content
 *
 * @return string HTML content for help sidebar.
 */
function ddw_gpex_help_sidebar_content() {

	$gpex_help_sidebar_content = '<p><strong>' . __( 'More about the plugin author', 'genesis-prose-extras' ) . '</strong></p>' .
			'<p>' . __( 'Social:', 'genesis-prose-extras' ) . '<br /><a href="http://twitter.com/deckerweb" target="_blank" title="@ Twitter">Twitter</a> | <a href="http://www.facebook.com/deckerweb.service" target="_blank" title="@ Facebook">Facebook</a> | <a href="http://deckerweb.de/gplus" target="_blank" title="@ Google+">Google+</a> | <a href="' . esc_url( ddw_gpex_plugin_get_data( 'AuthorURI' ) ) . '" target="_blank" title="@ deckerweb.de">deckerweb</a></p>' .
			'<p><a href="' . esc_url( GPEX_URL_WPORG_PROFILE ) . '" target="_blank" title="@ WordPress.org">@ WordPress.org</a></p>';

	return apply_filters( 'gpex_filter_help_sidebar_content', $gpex_help_sidebar_content );

}  // end of function ddw_gpex_help_sidebar_content


/**
 * Helper function for returning the Help Sidebar content - extra for plugin setting page.
 *
 * @since  1.0.0
 *
 * @param  $gpex_help_sidebar_content_extra
 *
 * @return string Extra HTML content for help sidebar.
 */
function ddw_gpex_help_sidebar_content_extra() {

	$gpex_help_sidebar_content_extra = '<p><strong>' . __( 'Actions', 'genesis-prose-extras' ) . '</strong></p>' .
		'<p>&rarr; <a href="' . esc_url( GPEX_URL_SUPPORT ) . '" target="_new">' . __( 'Support Forum', 'genesis-prose-extras' ) . '</a></p>' .
		'<p style="margin-top: -5px;">&rarr; <a href="' . esc_url( GPEX_URL_DONATE ) . '" target="_new">' . __( 'Donate', 'genesis-prose-extras' ) . '</a></p>';

	return apply_filters( 'gpex_filter_help_sidebar_content_extra', $gpex_help_sidebar_content_extra );

}  // end of function ddw_gpex_help_sidebar_content_extra


/**
 * Helper function for echoing extra space as HTML string.
 *
 * @since 1.0.0
 *
 * @param $gpex_space_helper
 */
function ddw_gpex_space_helper() {

	$gpex_space_helper = '<div style="height: 5px;"></div>';

	return $gpex_space_helper;

}  // end of function ddw_gpex_space_helper