<?php
/**
 * Helper functions for the admin.
 *
 * @package    Genesis Prose Extras
 * @subpackage Admin
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2013, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-prose-extras/
 * @link       http://deckerweb.de/twitter
 *
 * @since      1.0.0
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


add_action( 'admin_enqueue_scripts', 'ddw_gpex_load_admin_styles' );
/**
 * Load additional admin styles for Prose admin pages & Genesis admin pages.
 *
 * @since 1.0.0
 *
 * @uses  genesis_is_menu_page()
 * @uses  wp_register_style()
 * @uses  wp_enqueue_style()
 * @uses  wp_register_script()
 * @uses  wp_enqueue_script()
 */
function ddw_gpex_load_admin_styles( $hook_suffix ) {

	/** Register the stylesheet */
	wp_register_style(
		'prose-admin-extras',
		plugins_url( 'css/gpex-admin-styles' . GPEX_SCRIPT_SUFFIX . '.css', dirname( __FILE__ ) ),
		false,
		GPEX_VERSION,
		'all'
	);

	/** Register the script */
	wp_register_script(
		'gpex-admin-js',
		plugins_url( 'js/gpex-admin' . GPEX_SCRIPT_SUFFIX . '.js', dirname( __FILE__ ) ),
		array( 'jquery' ),
		GPEX_VERSION,
		true
	);
	
	/** Check for Genesis function, otherwise bail early */
	if ( ! function_exists( 'genesis_is_menu_page' ) ) {
		return;
	}

	/** If we're on a Genesis admin screen */
	if ( genesis_is_menu_page( 'gpex-prose-extras' )
		|| genesis_is_menu_page( 'design-settings' )
		|| genesis_is_menu_page( 'prose-custom' )
		|| genesis_is_menu_page( 'seo-settings' )
		|| genesis_is_menu_page( 'genesis' )
	) {

		/** Enqueue the stylesheet */
		wp_enqueue_style( 'prose-admin-extras' );

	}  // end-if Genesis pagehooks check

	if ( genesis_is_menu_page( 'prose-custom' ) || genesis_is_menu_page( 'genesis' ) ) {

		/** Enqueue the script */
		wp_enqueue_script( 'gpex-admin-js' );

	}

}  // end of function gpex_load_admin_styles


add_filter( 'genesis_export_options', 'ddw_gpex_export_options' );
/**
* Hook "Genesis Prose Extras" plugin into "Genesis Exporter", allowing
*    "Genesis Prose Extras" settings to be exported.
*
* @since  1.0.0
*
* @param  array $options Genesis Exporter options.
*
* @return array
*/
function ddw_gpex_export_options( array $options ) {

	/** Add original "Prose Custom" settings to the Genesis Exporter feature. */
	$options[ 'prosecustom' ] = array(
		'label'          => __( 'Prose Custom Code &amp; CSS', 'genesis-prose-extras' ),
		'settings-field' => 'prose-custom'
	);

	/** Add this plugin settings to the Genesis Exporter feature. */
	$options[ 'gpex' ] = array(
		'label'          => __( 'Plugin', 'genesis-prose-extras' ) . ': ' . __( 'Genesis Prose Extras', 'genesis-prose-extras' ),
		'settings-field' => 'gpex-settings'
	);

	/** Return the options array for the Exporter */
	return $options;

}  // end of function ddw_gpex_export_options


add_action( 'admin_notices', 'ddw_gpex_theme_editor_notice' );
add_action( 'network_admin_notices', 'ddw_gpex_theme_editor_notice' );
/**
* Display admin notice, if on the Theme Editor admin/ network admin page.
*
* @since  1.0.0
*
* @uses   is_super_admin()
* @uses   is_multisite()
* @uses   admin_url()
*
* @param  $gpex_prose_multisite_extras
* @param  $gpex_prose_notice
* @param  $gpex_prose_notice_mp6
*
* @global mixed $pagenow, $theme
*/
function ddw_gpex_theme_editor_notice() {

	/** Get the globals -- page hook for the admin page; plus current active theme */
	global $pagenow, $theme;

	/** Multisite Extras notice addition */
	if ( is_super_admin() && is_multisite() ) {

		$gpex_prose_multisite_extras = ' ' . sprintf( __( 'Within Multisite extra functions files could be used, see %s.', 'genesis-prose-extras' ), '<a href="' . admin_url( 'admin.php?page=gpex-prose-extras#gpex-multisite-files' ) . '">' . __( 'plugin settings', 'genesis-prose-extras' ) . '</a>' );

	} else {

		$gpex_prose_multisite_extras = '';

	}  // end-if super admin & multisite check

	/** Prose notice for theme editor */
	$gpex_prose_notice = sprintf(
		'&rarr; ' . __( 'Please use %1$s for any custom additions of CSS styles and functions.', 'genesis-prose-extras' ) . $gpex_prose_multisite_extras . '<br /><br />&rarr; ' . __( 'Tutorials or Snippets mentioning %2$s will go into %3$s, and stuff for %4$s will go into %5$s. Yes, it\'s that easy!', 'genesis-prose-extras' ) . ' ;-)',
		'<a href="' . admin_url( 'admin.php?page=prose-custom' ) . '"><em>' . __( 'Prose Custom Code', 'genesis-prose-extras' ) . '</em></a>',
		'<code>style.css</code>',
		'<a href="' . admin_url( 'admin.php?page=prose-custom#prose-custom-css' ) . '"><em>' . __( 'Prose Custom CSS', 'genesis-prose-extras' ) . '</em></a>',
		'<code>functions.php</code>',
		'<a href="' . admin_url( 'admin.php?page=prose-custom#prose-custom-php' ) . '"><em>' . __( 'Prose Custom PHP', 'genesis-prose-extras' ) . '</em></a>'
	);

	/** Add additional styling to notice if "MP6" plugin is active */
	$gpex_prose_notice_mp6 = function_exists( 'mp6_register_admin_color_scheme' ) ? ' style="padding: 1px 15px;"' : '';

	if ( function_exists( 'wp_get_theme' ) ) {
		$gpex_stylesheet_name = wp_get_theme( $stylesheet );
	}

	/** Check to see if we are on the Theme Editor admin/ network admin page */
	if ( 'theme-editor.php' == $pagenow ) {

		/** Do only display warning if we are within the "Prose" child theme */
		if ( ( $theme == 'Prose' ) || ( $theme == 'prose' ) || $gpex_stylesheet_name == 'Prose' ) {

			printf(
				'<div class="error"' . $gpex_prose_notice_mp6 . '><h4>%s</h4></div>',
				$gpex_prose_notice
			);

		}  // end-if "Prose" check

    }  // end-if $pagenow check

}  // end of function ddw_gpex_theme_editor_notice


/**
 * Helper function for returning capability for use of "Custom CSS" feature.
 *
 * @since 1.0.0
 */
function ddw_gpex_inpost_custom_css_cap() {
	
	return esc_attr( strtolower( apply_filters( 'gpex_filter_inpost_custom_css_cap', 'manage_options' ) ) );

}  // end of function ddw_gpex_inpost_custom_css_cap


add_action( 'admin_init', 'ddw_gpex_info_prose_custom', 50 );
/**
 * Helper function for loading our info boxes for Super Admins/ Admins.
 *
 * @since  1.0.0
 *
 * @uses   is_super_admin()
 *
 * @global $_prose_admin_design_settings, $_prose_custom_code
 */
function ddw_gpex_info_prose_custom() {

	/** Bail early if no super admin or Prose Child Theme */
	if ( ! is_super_admin() || ! defined( 'PROSE_DOMAIN' ) ) {
		return;
	}

    global $_prose_admin_design_settings, $_prose_custom_code;
    
    add_action( 'load-' . $_prose_custom_code->pagehook, 'ddw_gpex_info_prose_metaboxes', 20 );
    add_action( 'load-' . $_prose_admin_design_settings->pagehook, 'ddw_gpex_info_prose_metaboxes', 20 );

}  // end of function ddw_gpex_info_prose_custom


/**
 * Helper function for adding meta boxes to the default Prose admin pages.
 *
 * @since 1.0.0
 *
 * @uses   add_meta_box()
 *
 * @param  string 	$gpex_via
 *
 * @global $_prose_admin_design_settings, $_prose_custom_code
 */
function ddw_gpex_info_prose_metaboxes() {

    global $_prose_admin_design_settings, $_prose_custom_code;

	$gpex_via = ' <small>(' . sprintf( __( 'via %s', 'genesis-prose-extras' ), __( 'Genesis Prose Extras', 'genesis-prose-extras' ) ) . ')</small>';

    add_meta_box(
    	'gpex-info-prose-design',
    	__( 'Admin Info', 'genesis-prose-extras' ) . $gpex_via,
    	'ddw_gpex_info_prose_custom_content',
    	$_prose_admin_design_settings->pagehook,
    	'main',
    	'high'
    );

    add_meta_box(
    	'gpex-info-prose-custom',
    	__( 'Admin Info', 'genesis-prose-extras' ) . $gpex_via,
    	'ddw_gpex_info_prose_custom_content',
    	$_prose_custom_code->pagehook,
    	'main',
    	'high'
    );

}  // end of function ddw_gpex_info_prose_custom_metabox


/**
 * Display our info content for Super Admins/ Admins.
 *
 * @since 1.0.0
 *
 * @uses  genesis_is_menu_page()
 * @uses  is_multisite()
 * @uses  ddw_gpex_help_content_custom_css_advice()
 */
function ddw_gpex_info_prose_custom_content() {

	/** Begin form code */
	?>

		<?php if ( genesis_is_menu_page( 'prose-custom' ) ) : ?>
			<h4>
				&rarr; <?php _e( 'Better Custom PHP - Global Prose Functions', 'genesis-prose-extras' ); ?>
			</h4>

		    <p>
		    	<ul>
		    		<li><?php echo sprintf(
		    				__( 'If you have no success with the %s area below, just place a functions file named %s within %s.', 'genesis-prose-extras' ),
		    				'<em>' . __( 'Custom PHP Code', 'genesis-prose-extras' ) . '</em>',
		    				'<code>gpex-custom-code.php</code>',
		    				'<code>/wp-content/uploads/prose/</code>'
		    			); ?></li>
		    		<?php if ( is_multisite() ) : ?>
		    			<li><?php echo sprintf(
		    					__( 'This works globally for Prose - for per Site functions use our special plugin\'s feature via %s.', 'genesis-prose-extras' ),
		    					'<a href="' . admin_url( 'admin.php?page=gpex-prose-extras' ) . '#gpex-multisite-files">' . __( 'plugin settings', 'genesis-prose-extras' ) . '</a>'
		    				); ?></li>
		    		<?php endif; ?>
		    	<ul>
		    </p>

			<hr class="div" />

		<?php endif; ?>

	    <h4>
	    	&rarr; <?php _e( 'Custom CSS for Single Posts/ Pages', 'genesis-prose-extras' ); ?>
	    </h4>
	    
	    <?php ddw_gpex_help_content_custom_css_advice(); ?>
	                    
	<?php
	/** ^End form code */

}  // end of function ddw_gpex_info_prose_custom_content