<?php
/**
 * Load frontend relevant functions/ logic for Prose Child Theme.
 *
 * @package    Genesis Prose Extas
 * @subpackage Frontend/ Templates
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2013, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-prose-extras/
 * @link       http://deckerweb.de/twitter
 *
 * @since      1.0.0
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


add_action( 'wp_enqueue_scripts', 'ddw_gpex_register_frontend_styles', 11 );
/**
 * Register our additional frontend helper styles.
 *
 * @since 1.0.0
 *
 * @uses  wp_register_style()
 * @uses  genesis_html5()
 *
 * @param string 	$gpex_genesis_html
 */
function ddw_gpex_register_frontend_styles() {

	/** Check for Genesis HTML5 */
	$gpex_genesis_html = ( function_exists( 'genesis_html5' ) && genesis_html5() ) ? 'html5-' : '';

 	/** Register the stylesheet */
	wp_register_style(
		'prose-extras-frontend',
		plugins_url( 'css/gpex-frontend-' . $gpex_genesis_html . 'styles' . GPEX_SCRIPT_SUFFIX . '.css', dirname( __FILE__ ) ),
		false,
		( ( defined( 'WP_DEBUG' ) && WP_DEBUG ) || ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ) ? time() : filemtime( plugin_dir_path( __FILE__ ) ),
		'all'
	);

}  // end of function ddw_gpex_register_frontend_styles


add_action( 'genesis_meta', 'ddw_gpex_menu_positions' );
/**
 * Optionally reposition the Primary Navigation below header.
 *
 * @since 1.0.0
 *
 * @uses  genesis_get_option()
 * @uses  remove_action()
 * @uses  add_action()
 *
 * @param $gpex_menu_positions
 */
function ddw_gpex_menu_positions() {

	/** Get the settings from the settings field */
	$gpex_menu_positions = genesis_get_option( 'menu_positions', 'gpex-settings' );

	/** Reverse Primary (now bottom) and Secondary (now top) */
	if ( 'reverse_default' == $gpex_menu_positions ) {

		remove_action( 'genesis_before_header', 'genesis_do_nav' );
		add_action( 'genesis_after_header', 'genesis_do_nav', 9 );

		remove_action( 'genesis_after_header', 'genesis_do_subnav' );
		add_action( 'genesis_before_header', 'genesis_do_subnav' );

	}

	/** Both navigations above #header */
	if ( 'double_above' == $gpex_menu_positions ) {

		remove_action( 'genesis_after_header', 'genesis_do_subnav' );
		add_action( 'genesis_before_header', 'genesis_do_subnav', 11 );

	}

	/** Both navigations below #header */
	if ( 'double_below' == $gpex_menu_positions ) {

		remove_action( 'genesis_before_header', 'genesis_do_nav' );
		add_action( 'genesis_after_header', 'genesis_do_nav', 9 );

	}

	/** Primary as "top bar", outside the #wrap */
	if ( 'primary_topbar' == $gpex_menu_positions ) {

		remove_action( 'genesis_before_header', 'genesis_do_nav' );
		add_action( 'genesis_before', 'genesis_do_nav' );

	}

	/** Secondary as "top bar", outside the #wrap */
	if ( 'secondary_topbar' == $gpex_menu_positions ) {

		remove_action( 'genesis_after_header', 'genesis_do_subnav' );
		add_action( 'genesis_before', 'genesis_do_subnav' );

		remove_action( 'genesis_before_header', 'genesis_do_nav' );
		add_action( 'genesis_after_header', 'genesis_do_nav', 9 );

	}

}  // end of function ddw_gpex_menu_positions


/**
 * Add descriptions to Primary & Secondary navigation menus.
 *
 * @since 1.0.0
 *
 * @uses  genesis_get_option()
 */
if ( function_exists( 'genesis_get_option' ) && genesis_get_option( 'menu_descriptions', 'gpex-settings' ) ) {

	add_filter( 'walker_nav_menu_start_el', 'ddw_gpex_add_menu_descriptions', 10, 4 );
	/**
	 * Hook into Nav Waler filter to add menu descriptions to the menu link.
	 *
	 * @since  1.0.0
	 *
	 * @param  $item_output
	 * @param  $item
	 * @param  $depth
	 * @param  $args
	 *
	 * @return string Nav Menu item with link plus added description string(s).
	 */
	function ddw_gpex_add_menu_descriptions( $item_output, $item, $depth, $args ) {

		$args = (array) $args;

		/** Check for Menu theme locations */
		if ( $args[ 'theme_location' ] == ( 'primary' || 'secondary' ) ) {

			return preg_replace( '/(<a.*?>[^<]*?)</', '$1' . "<span class=\"menu-description\">{$item->post_content}</span><", $item_output );

		} else {

			return $item_output;

		}  // end-if menu location check

	}  // end of function ddw_gpex_add_menu_descriptions


	add_action( 'wp_enqueue_scripts', 'ddw_gpex_nav_frontend_styles', 12 );
	/**
	 * Load our additional frontend helper styles.
	 *
	 * @since 1.0.0
	 *
	 * @uses  wp_enqueue_style()
	 */
	function ddw_gpex_nav_frontend_styles() {

		wp_enqueue_style( 'prose-extras-frontend' );

	}  // end of function ddw_gpex_nav_frontend_styles

}  // end if menu descriptions check


add_action( 'genesis_meta', 'ddw_gpex_footer_widgets_home' );
/**
 * Optionally remove footer widgets on home page/ static front page.
 *
 * @since 1.0.0
 *
 * @uses  genesis_get_option()
 * @uses  remove_theme_support()
 */
function ddw_gpex_footer_widgets_home() {

	if ( ( function_exists( 'genesis_get_option' ) && genesis_get_option( 'home_no_footer_widgets', 'gpex-settings' ) )
		&& ( is_home() || is_front_page() )
	) {

		remove_theme_support( 'genesis-footer-widgets' );

	}  // end-if settings & home/ front page check

}  // end of function ddw_gpex_footer_widgets_home


add_action( 'wp_head', 'ddw_gpex_singular_custom_css', 20 );
/**
 * Inject the custom CSS in 'wp_head' header section.
 *
 * @since 1.0.0
 *
 * @uses  genesis_get_custom_field()
 * @uses  is_singular()
 * @uses  prose_minify_css()
 *
 * @param $gpex_singular_css
 */
function ddw_gpex_singular_custom_css() {

	/** Bail early if Prose minify is not available */
	if ( ! function_exists( 'prose_minify_css' ) ) {
		return;
	}

	$gpex_singular_css = genesis_get_custom_field( '_gpex_inpost_custom_css' );

	/** If singular, echo scripts from custom field */
	if ( is_singular() ) {

		echo sprintf(
			'<style type="text/css">%s</style>',
			prose_minify_css( $gpex_singular_css )
		);

  	}  // end-if is_singular() check

}  // end of function ddw_gpex_singular_custom_css


add_action( 'genesis_after_post_content', 'ddw_gpex_after_page_widget' );	// XHTMTL, pre G2.0
add_action( 'genesis_entry_footer', 'ddw_gpex_after_page_widget' );			// HTML5, G2.0+
/**
 * After Page widget area.
 *
 * Output widget area after the page content.
 *
 * @since 1.0.0
 *
 * @uses  genesis_get_option()
 * @uses  genesis_widget_area()
 */
function ddw_gpex_after_page_widget() {

	if ( ! is_singular( 'page' ) || ( function_exists( 'genesis_get_option' ) && ! genesis_get_option( 'after_page_widget_area', 'gpex-settings' ) ) ) {
		return;
	}

	genesis_widget_area( 'gpex-prose-after-page', array(
		'before' => '<div class="gpex-after-page after-post widget-area">',
	) );

}  // end of function ddw_gpex_after_page_widget


add_action( 'genesis_meta', 'ddw_gpex_remove_after_post_widget' );
/**
 * Testing
 *
 * @since 1.0.0
 *
 * @uses  genesis_get_option()
 */
function ddw_gpex_remove_after_post_widget() {

	if ( is_singular( 'post' ) && ( function_exists( 'genesis_get_option' ) && ! genesis_get_option( 'after_post_widget_area', 'gpex-settings' ) ) ) {

		remove_action( 'genesis_after_post_content', 'prose_after_post' );	// XHTMTL, pre G2.0
		remove_action( 'genesis_entry_footer', 'prose_after_post' );		// HTML5, G2.0+

	}  // end-if is_singular() & settings check

}  // end of function ddw_gpex_remove_after_post_widget


add_action( 'genesis_meta', 'ddw_gpex_do_additional_layouts' );
/**
 * @since 1.0.0
 *
 * @uses  genesis_site_layout()
 *
 * @param string 	$gpex_site_layout
 */
function ddw_gpex_do_additional_layouts() {

	/** Get registered layouts */
	$gpex_site_layout = genesis_site_layout();

	/** Drop Primary Sidebar if our Sidebar-Alt layouts are active */
	if ( 'content-sidebaralt' == $gpex_site_layout || 'sidebaralt-content' == $gpex_site_layout ) {

		remove_action( 'genesis_after_content', 'genesis_get_sidebar' );	// XHTMTL, pre G2.0
		remove_action( 'genesis_after_entry', 'genesis_get_sidebar' );		// HTML5, G2.0+

	}  // end-if layout check

	/** For Sidebars below Content tweak sidebar positions */
	if ( 'sidebars-below-content' == $gpex_site_layout ) {

		remove_action( 'genesis_after_content', 'genesis_get_sidebar' );	// XHTMTL, pre G2.0
		remove_action( 'genesis_after_entry', 'genesis_get_sidebar' );		// HTML5, G2.0+

		remove_action( 'genesis_after_content_sidebar_wrap', 'genesis_get_sidebar_alt' );

		add_action( 'genesis_after_content_sidebar_wrap', 'ddw_gpex_do_layout_sidebars_below_content' );

	}  // end-if layout check

}  // end of function ddw_gpex_do_additional_layouts


/**
 * Setup structure for layout "Sidebars below Content".
 *    Primary gets loaded before Secondary but Secondary is displayed on the
 *    left, and Primary on the right.
 *
 * @since 1.0.0
 *
 * @uses  get_sidebar()
 */
function ddw_gpex_do_layout_sidebars_below_content() {
	
	echo '<div class="gpex-sidebars-below-content">';

		echo '<div class="one-half second gpex-columns">';
			
			get_sidebar();

		echo '</div>';

		echo '<div class="one-half first gpex-columns">';

			get_sidebar( 'alt' );

		echo '</div>';

	echo '</div><div class="clear"></div>';

}  // end of function ddw_gpex_do_layout_sidebars_below_content


add_action( 'wp_enqueue_scripts', 'ddw_gpex_layouts_frontend_styles', 15 );
/**
 * Load our additional frontend helper styles if alternate layouts are used.
 *
 * @since 1.0.0
 *
 * @uses  genesis_site_layout()
 * @uses  wp_enqueue_style()
 *
 * @param string 	$gpex_site_layout
 */
function ddw_gpex_layouts_frontend_styles() {

	/** Bail early if Genesis is not present, i.e. if Jetpack Mobile Theme is active */
	if ( ! function_exists( 'genesis_site_layout' ) ) {
		return;
	}

	/** Get registered layouts */
	$gpex_site_layout = genesis_site_layout();

	/** Check for our alternate layouts */
	if ( 'sidebars-below-content' == $gpex_site_layout
		|| 'content-sidebaralt' == $gpex_site_layout
		|| 'sidebaralt-content' == $gpex_site_layout
	) {

		wp_enqueue_style( 'prose-extras-frontend' );

	}  // end-if layout check

}  // end of function ddw_gpex_layouts_frontend_styles