<?php
/**
 * Load Multisite/ Network specific functions for Prose Child Theme.
 *
 * @package    Genesis Prose Extas
 * @subpackage Multisite
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2013, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-prose-extras/
 * @link       http://deckerweb.de/twitter
 *
 * @since      1.0.0
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


/**
 * Helper function for setting action hook handle via plugin settings.
 *
 * @since 1.0.0
 *
 * @uses  genesis_get_option()
 *
 * @param $gpex_multisite_function_hook
 */
function ddw_gpex_multisite_hook_helper() {

	/** Bail early if there's no Genesis active */
	if ( ! function_exists( 'genesis_get_option' ) ) {
		return;
	}

	/** Get the settings from the settings field */
	$gpex_multisite_function_hook = genesis_get_option( 'multisite_hook', 'gpex-settings' );

	return $gpex_multisite_function_hook;

}  // end of function ddw_gpex_multisite_hook_helper


/**
 * Helper function for setting action hook priority via plugin settings.
 *
 * @since 1.0.0
 *
 * @uses  genesis_get_option()
 *
 * @param $gpex_multisite_function_priority
 */
function ddw_gpex_multisite_priority_helper() {

	/** Bail early if there's no Genesis active */
	if ( ! function_exists( 'genesis_get_option' ) ) {
		return;
	}

	/** Get the settings from the settings field */
	$gpex_multisite_function_priority = (int) genesis_get_option( 'multisite_priority', 'gpex-settings' );

	return $gpex_multisite_function_priority;

}  // end of function ddw_gpex_multisite_priority_helper


/**
 * Define Action Hook handle name constant.
 *
 * @since 1.0.0
 */
if ( ! defined( 'GPEX_MULTISITE_FUNCTION_HOOK' ) ) {
	define(
		'GPEX_MULTISITE_FUNCTION_HOOK',
		apply_filters( 'gpex_filter_multisite_functions_hook', ddw_gpex_multisite_hook_helper() )
	);
}


/**
 * Define Action Hook priority constant.
 *
 * @since 1.0.0
 */
if ( ! defined( 'GPEX_MULTISITE_FUNCTION_HOOK_PRIORITY' ) ) {
	define(
		'GPEX_MULTISITE_FUNCTION_HOOK_PRIORITY',
		apply_filters( 'gpex_filter_multisite_functions_hook_priority', ddw_gpex_multisite_priority_helper() )
	);
}


add_action( GPEX_MULTISITE_FUNCTION_HOOK, 'ddw_gpex_include_site_specific_functions', GPEX_MULTISITE_FUNCTION_HOOK_PRIORITY );
/**
 * Pull in site-specific functions.php files, if available.
 *
 * @since  1.0.0
 *
 * @uses   genesis_get_option()
 * @uses   prose_get_stylesheet_location()
 *
 * @param  $gpex_multisite
 * @param  $gpex_site_file
 *
 * @global integer $blog_id 
 */
function ddw_gpex_include_site_specific_functions() {

	/** Bail early if there's no Prose Child Theme active */
	if ( ! function_exists( 'prose_get_stylesheet_location' ) ) {
		return;
	}

	/** Get the Site/ Blog ID */
	global $blog_id;

	/** Get the settings from the settings field */
	$gpex_multisite = function_exists( 'genesis_get_option' ) ? genesis_get_option( 'multisite_files', 'gpex-settings' ) : false;

	/** Set the functions file path */
	$gpex_site_file = prose_get_stylesheet_location( 'path' ) . 'functions-site-' . $blog_id . '.php';

	/** Include the additional functions file per site, if an appropriate file is available */
	if ( $gpex_multisite && is_readable( $gpex_site_file ) ) {

		require_once( $gpex_site_file );

	}  // end-if file check

}  // end of function ddw_gpex_include_site_specific_functions