<?php
/**
 * Load the extra Homepage template for Prose Child Theme.
 *
 * @package    Genesis Prose Extas
 * @subpackage Templates
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2013, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-prose-extras/
 * @link       http://deckerweb.de/twitter
 *
 * @since      1.0.0
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


/**
 * Load the additional, "virtual" Homepage template.
 *    - Hooked to 'template_include' filter.
 *
 * @since  1.0.0
 *
 * @uses   is_home()
 * @uses   locate_template()
 * @uses   prose_get_stylesheet_location()
 *
 * @param  string $template Template file as per template hierarchy
 *
 * @return string $template Homepage template
 */
function ddw_gpex_template_loader( $template ) {

	/** Is Homepage (is_home()) */
	if ( is_home() ) {

		/** Use custom template via child theme (child root) */
		$template = locate_template( array( 'prose-home.php' ) );

		/** Search within Prose 1.5+ stylesheet directory */
		if ( ! $template && is_readable( prose_get_stylesheet_location( 'url' ) . '/prose-home.php' ) ) {

			$template = prose_get_stylesheet_location( 'url' ) . '/prose-home.php';

		}  // end-if

		/** Fallback to GPEX template (plugin) */
		if ( ! $template ) {

			$template = GPEX_TEMPLATE_DIR . '/prose-home.php';
			
		}  // end-if

	}  // end-if is_home check

	/** Return the template */
	return $template;

}  // end of function ddw_gpex_template_loader