<?php
/**
 * Register additional widget areas.
 *
 * @package    Genesis Prose Extras
 * @subpackage Widgets
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2013, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-prose-extras/
 * @link       http://deckerweb.de/twitter
 *
 * @since      1.0.0
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


add_action( 'init', 'ddw_gpex_register_widget_areas' );
/**
 * Register additional widget areas
 *
 * Note: Has to be early on the "init" hook in order to display translations!
 *
 * @since 1.0.0
 *
 * @uses  genesis_get_option()
 * @uses  genesis_register_sidebar()
 */
function ddw_gpex_register_widget_areas() {

	/** Check for activated Genesis Framework (= template/parent theme) */
	if ( ( basename( get_template_directory() ) == 'genesis' ) && function_exists( 'genesis_get_option' ) ) {

		/** Add shortcode support to widgets */
		if ( ! GPEX_NO_WIDGETS_SHORTCODE && ! is_admin() ) {

			add_filter( 'widget_text', 'do_shortcode' );

		}  // end-if constant check

		/** Register "Home Top" area if enabeld in plugin settings */
		if ( genesis_get_option( 'home_top_widget_area', 'gpex-settings' ) ) {

			/** Set filter for "Home Top" widget title */
			$gpex_home_top_widget_title = apply_filters(
				'gpex_filter_home_top_widget_title',
				__( 'Prose Home Top', 'genesis-prose-extras' )
			);

			/** Set filter for "Home Top" widget description */
			$gpex_home_top_widget_description = apply_filters(
				'gpex_filter_homepage_top_widget_description',
				__( 'For a widgetized homepage in Prose.', 'genesis-prose-extras' )
			);

			/** Register additional widget area/sidebar: Home Top (default width) */
			genesis_register_sidebar(
				array(
					'id'            => 'gpex-prose-home-top',
					'name'          => esc_attr__( $gpex_home_top_widget_title ),
					'description'   => esc_attr__( $gpex_home_top_widget_description ),
					'before_widget' => '<div id="%1$s" class="prose-home-top widget %2$s">',
					'after_widget'  => '</div>',
				)
			);

		}  // end-if settings check

		/** Register "Home Left" area if enabeld in plugin settings */
		if ( genesis_get_option( 'home_left_widget_area', 'gpex-settings' ) ) {

			/** Set filter for "Homepage Left" widget title */
			$gpex_home_left_widget_title = apply_filters(
				'gpex_filter_home_left_widget_title',
				__( 'Prose Home Left', 'genesis-prose-extras' )
			);

			/** Set filter for "Homepage Left" widget description */
			$gpex_home_left_widget_description = apply_filters(
				'gpex_filter_home_left_widget_description',
				__( 'Home left area for a widgetized homepage in Prose.', 'genesis-prose-extras' )
			);

			/** Register additional widget area/sidebar: Home Left (50% width) */
			genesis_register_sidebar(
				array(
					'id'            => 'gpex-prose-home-left',
					'name'          => esc_attr__( $gpex_home_left_widget_title ),
					'description'   => esc_attr__( $gpex_home_left_widget_description ),
					'before_widget' => '<div id="%1$s" class="prose-home-left widget %2$s">',
					'after_widget'  => '</div>',
				)
			);

		}  // end-if settings check

		/** Register "Home Right" area if enabeld in plugin settings */
		if ( genesis_get_option( 'home_right_widget_area', 'gpex-settings' ) ) {

			/** Set filter for "Homepage Right" widget title */
			$gpex_home_right_widget_title = apply_filters(
				'gpex_filter_home_right_widget_title',
				__( 'Prose Home Right', 'genesis-prose-extras' )
			);

			/** Set filter for "Homepage Right" widget description */
			$gpex_home_right_widget_description = apply_filters(
				'gpex_filter_home_right_widget_description',
				__( 'Home right area for a widgetized homepage in Prose.', 'genesis-prose-extras' )
			);

			/** Register additional widget area/sidebar: Home Right (50% width) */
			genesis_register_sidebar(
				array(
					'id'            => 'gpex-prose-home-right',
					'name'          => esc_attr__( $gpex_home_right_widget_title ),
					'description'   => esc_attr__( $gpex_home_right_widget_description ),
					'before_widget' => '<div id="%1$s" class="prose-home-right widget %2$s">',
					'after_widget'  => '</div>',
				)
			);

		}  // end-if settings check

		/** Register "Home Extra Sidebar" if enabeld in plugin settings */
		if ( genesis_get_option( 'home_extra_sidebar', 'gpex-settings' ) ) {

			/** Set filter for "Homepage Extra" widget title */
			$gpex_home_extra_widget_title = apply_filters(
				'gpex_filter_home_extra_widget_title',
				__( 'Prose Home Sidebar', 'genesis-prose-extras' )
			);

			/** Set filter for "Homepage Extra" widget description */
			$gpex_home_extra_widget_description = apply_filters(
				'gpex_filter_home_extra_widget_description',
				__( 'Home extra sidebar replacing Genesis primary sidebar for the homepage in Prose.', 'genesis-prose-extras' )
			);

			/** Register additional widget area/sidebar: Home Extra Sidebar */
			genesis_register_sidebar(
				array(
					'id'            => 'gpex-prose-home-extra',
					'name'          => esc_attr__( $gpex_home_extra_widget_title ),
					'description'   => esc_attr__( $gpex_home_extra_widget_description ),
					'before_widget' => '<div id="%1$s" class="prose-home-extra widget %2$s">',
					'after_widget'  => '</div>',
				)
			);

		}  // end-if settings check


		/** Register "After Page" area if enabeld in plugin settings */
		if ( genesis_get_option( 'after_page_widget_area', 'gpex-settings' ) ) {

			/** Set filter for "After Page" widget title */
			$gpex_after_page_widget_title = apply_filters(
				'gpex_filter_after_page_widget_title',
				__( 'Prose After Page', 'genesis-prose-extras' )
			);

			/** Set filter for "After Page" widget description */
			$gpex_after_page_widget_description = apply_filters(
				'gpex_filter_after_page_widget_description',
				__( 'Widget area after page content.', 'genesis-prose-extras' )
			);

			/** Register additional widget area/sidebar: After Page widget area (sidebar) */
			genesis_register_sidebar(
				array(
					'id'            => 'gpex-prose-after-page',
					'name'          => esc_attr__( $gpex_after_page_widget_title ),
					'description'   => esc_attr__( $gpex_after_page_widget_description ),
					'before_widget' => '<div id="%1$s" class="prose-after-page widget %2$s">',
					'after_widget'  => '</div>',
				)
			);

		}  // end-if settings check

		/** Conditionally un-register (default) "After Post" area if set in plugin settings */
		if ( ! genesis_get_option( 'after_post_widget_area', 'gpex-settings' ) ) {

			unregister_sidebar( 'after-post' );

		}  // end-if settings check

	}  // end-if Genesis check

}  // end of function ddw_gpex_register_widget_areas