<?php
/**
 * Prose Homepage Layout.
 *
 * @package    Genesis Prose Extras
 * @subpackage Templates
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2013, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-prose-extras/
 * @link       http://deckerweb.de/twitter
 *
 * @since      1.0.0
 */

add_filter( 'genesis_pre_get_option_site_layout', 'ddw_gpex_home_layout' );
/**
 * Set layout option from plugin settings.
 *
 * @since  1.0.0
 *
 * @uses   genesis_get_option()
 *
 * @param  $layout_option
 * @param  $gpex_home_layout
 *
 * @return string Genesis layout option for is_home().
 */
function ddw_gpex_home_layout( $layout_option ) {

	$gpex_home_layout = genesis_get_option( 'home_layout', 'gpex-settings' );

	return $gpex_home_layout;

}  // end of function ddw_gpex_home_layout


remove_action( 'genesis_loop', 'genesis_do_loop' );
add_action( 'genesis_loop', 'ddw_gpex_prose_home_loop_helper' );
/**
 * Add widget support for the additional, "virtual" Homepage template.
 *   If no widgets are active, display the Genesis default loop.
 *
 * @since 1.0.0
 *
 * @uses  is_active_sidebar()
 * @uses  dynamic_sidebar()
 * @uses  genesis_standard_loop()
 */
function ddw_gpex_prose_home_loop_helper() {

	$gpex_home_top   = genesis_get_option( 'home_top_widget_area', 'gpex-settings' );
	$gpex_home_left  = genesis_get_option( 'home_left_widget_area', 'gpex-settings' );
	$gpex_home_right = genesis_get_option( 'home_right_widget_area', 'gpex-settings' );

	/** Fallback if all widget areas are unregistered */
	if ( ! $gpex_home_top && ! $gpex_home_left && ! $gpex_home_right ) {

		genesis_standard_loop();

	}  // end-if settings check

	/** Check for active widget area */
	if ( is_active_sidebar( 'gpex-prose-home-top' )
		&& ( is_active_sidebar( 'gpex-prose-home-left' ) || is_active_sidebar( 'gpex-prose-home-right' ) )
	) {

		echo '<div id="prose-home">';

			dynamic_sidebar( 'gpex-prose-home-top' );

			if ( $gpex_home_top ) {
				echo '<div class="gpex-widget-area-sep"></div>';
			}

			echo '<div class="one-half first gpex-columns">';
				dynamic_sidebar( 'gpex-prose-home-left' );
			echo '</div>';

			echo '<div class="one-half gpex-columns">';
				dynamic_sidebar( 'gpex-prose-home-right' );
			echo '</div>';

			echo '<div class="clear"></div>';

		echo '</div><!-- end #prose-home -->';
		
	} elseif ( is_active_sidebar( 'gpex-prose-home-top' )
			&& ( ! is_active_sidebar( 'gpex-prose-home-left' ) && ! is_active_sidebar( 'gpex-prose-home-right' ) )
	) {

		echo '<div id="prose-home">';

			dynamic_sidebar( 'gpex-prose-home-top' );

		echo '</div><!-- end #prose-home -->';

	} elseif ( ( ! is_active_sidebar( 'gpex-prose-home-top' ) || ! $gpex_home_top )
			&& ( is_active_sidebar( 'gpex-prose-home-left' ) || is_active_sidebar( 'gpex-prose-home-right' ) )
	) {

		echo '<div id="prose-home">';

			echo '<div class="one-half first gpex-columns">';
				dynamic_sidebar( 'gpex-prose-home-left' );
			echo '</div>';

			echo '<div class="one-half gpex-columns">';
				dynamic_sidebar( 'gpex-prose-home-right' );
			echo '</div>';

			echo '<div class="clear"></div>';

		echo '</div><!-- end #prose-home -->';

	} elseif ( ( ! is_active_sidebar( 'gpex-prose-home-top' ) && ( ! is_active_sidebar( 'gpex-prose-home-left' ) && ! is_active_sidebar( 'gpex-prose-home-right' ) ) ) 
	) {

		genesis_standard_loop();

	}  // end-if widget area check

}  // end of function ddw_gpex_prose_home_loop_helper


/**
 * Replace primary sidebar with extra sidebar - only when is_home()
 *
 * @since 1.0.0
 */
if ( ( function_exists( 'genesis_get_option' ) && genesis_get_option( 'home_extra_sidebar', 'gpex-settings' ) )
	&& is_active_sidebar( 'gpex-prose-home-extra' )
) {

	/** First, remove Genesis Primary Sidebar */
	remove_action( 'genesis_sidebar', 'genesis_do_sidebar' );

	/** Then add our extra sidebar */
	add_action( 'genesis_sidebar', 'ddw_gpex_home_extra_sidebar' );

}  // end-if settings & active sidebar check


/**
 * Display Home Extra Sidebar.
 *
 * @since 1.0.0
 *
 * @uses  dynamic_sidebar()
 */
function ddw_gpex_home_extra_sidebar() {

	dynamic_sidebar( 'gpex-prose-home-extra' );

}  // end of function ddw_gpex_home_extra_sidebar


add_action( 'wp_enqueue_scripts', 'ddw_gpex_frontend_styles', 12 );
/**
 * Load our additional frontend helper styles.
 *
 * @since 1.0.0
 *
 * @uses  is_active_sidebar()
 * @uses  wp_enqueue_style()
 */
function ddw_gpex_frontend_styles() {

	/** Enqueue our styles */
	if ( is_active_sidebar( 'gpex-prose-home-top' )
		|| is_active_sidebar( 'gpex-prose-home-left' )
		|| is_active_sidebar( 'gpex-prose-home-right' )
	) {

		wp_enqueue_style( 'prose-extras-frontend' );

	}  // end-if widget areas check

}  // end of function ddw_gpex_frontend_styles


/** Let Genesis take over again :) */
genesis();